Struct collections::fmt::Formatter
[−]
[src]
pub struct Formatter<'a> {
// some fields omitted
}1.0.0A struct to represent both where to emit formatting strings to and how they should be formatted. A mutable version of this is passed to all formatting traits.